Recurrent
------------------------

.. automodule:: flax.nnx.nn.recurrent
.. currentmodule:: flax.nnx.nn.recurrent

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: LSTMCell

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: OptimizedLSTMCell

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: SimpleCell

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: GRUCell

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: RNN

.. flax_module::
  :module: flax.nnx.nn.recurrent
  :class: Bidirectional


.. autofunction:: flip_sequences